@@ -1,41 +1,33 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Copyright (C) 2013 BlackBerry Limited. All rights reserved.
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -159,7 +151,19 @@ void QDeclarativeBluetoothDiscoveryModel::componentComplete()
 
 void QDeclarativeBluetoothDiscoveryModel::errorDiscovery(QBluetoothServiceDiscoveryAgent::Error error)
 {
-    d->m_error = static_cast<QDeclarativeBluetoothDiscoveryModel::Error>(error);
+    switch (error) {
+    case QBluetoothServiceDiscoveryAgent::InvalidBluetoothAdapterError:
+        d->m_error = QDeclarativeBluetoothDiscoveryModel::InvalidBluetoothAdapterError; break;
+    case QBluetoothServiceDiscoveryAgent::NoError:
+        d->m_error = QDeclarativeBluetoothDiscoveryModel::NoError; break;
+    case QBluetoothServiceDiscoveryAgent::InputOutputError:
+        d->m_error = QDeclarativeBluetoothDiscoveryModel::InputOutputError; break;
+    case QBluetoothServiceDiscoveryAgent::PoweredOffError:
+        d->m_error = QDeclarativeBluetoothDiscoveryModel::PoweredOffError; break;
+    case QBluetoothServiceDiscoveryAgent::UnknownError:
+        d->m_error = QDeclarativeBluetoothDiscoveryModel::UnknownError; break;
+    }
+
     emit errorChanged();
 }
 
@@ -195,6 +199,12 @@ void QDeclarativeBluetoothDiscoveryModel::clearModel()
          \li An IO failure occurred during device discovery
     \row \li \c BluetoothDiscoveryModel.PoweredOffError
          \li The bluetooth device is not powered on.
+    \row \li \c BluetoothDiscoveryModel.InvalidBluetoothAdapterError
+         \li There is no default Bluetooth device to perform the
+             service discovery. The model always uses the local default adapter.
+             Specifying a default adapter is not possible. If that's required,
+             \l QBluetoothServiceDiscoveryAgent should be directly used. This
+             value was introduced by Qt 5.4.
     \row \li \c BluetoothDiscoveryModel.UnknownError
          \li An unknown error occurred.
     \endtable
@@ -415,10 +425,17 @@ void QDeclarativeBluetoothDiscoveryModel::setRunning(bool running)
                 //qDebug() << "Minimal Discovery";
                 d->m_serviceAgent->start(QBluetoothServiceDiscoveryAgent::MinimalDiscovery);
             }
+
+            // we could not start service discovery
+            if (!d->m_serviceAgent->isActive()) {
+                d->m_running = false;
+                errorDiscovery(d->m_serviceAgent->error());
+                return;
+            }
         }
     }
 
-    Q_EMIT runningChanged();
+    emit runningChanged();
 }
 
 /*!
@@ -472,5 +489,5 @@ QString QDeclarativeBluetoothDiscoveryModel::remoteAddress()
 void QDeclarativeBluetoothDiscoveryModel::setRemoteAddress(QString address)
 {
     d->m_remoteAddress = address;
-    Q_EMIT remoteAddressChanged();
+    emit remoteAddressChanged();
 }
