@@ -1,40 +1,32 @@
 /****************************************************************************
 **
-** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
+** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
 ** Contact: http://www.qt-project.org/legal
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -250,13 +242,27 @@ void tst_QBluetoothDeviceDiscoveryAgent::tst_startStopDeviceDiscoveries()
     QVERIFY(discoveryAgent.error() == discoveryAgent.NoError);
     QVERIFY(discoveryAgent.errorString().isEmpty());
 
+    /*
+        Starting case 4: start-stop-start-stop:
+        We are testing that two subsequent stop() calls reduce total number
+        of cancel() signals to 1 if the true cancellation requires
+        asynchronous function calls (signal consolidation); otherwise we
+        expect 2x cancel() signal.
 
-    // Starting case 4: start-stop-start-stop, expecting only 1 cancel signal
+        Examples are:
+            - Bluez4 (event loop needs to run for cancel)
+            - Bluez5 (no event loop required)
+    */
+
+    bool immediateSignal = false;
     discoveryAgent.start();
     QVERIFY(discoveryAgent.isActive());
     QVERIFY(errorSpy.isEmpty());
     // cancel current request.
     discoveryAgent.stop();
+    //should only have triggered cancel() if stop didn't involve the event loop
+    if (cancelSpy.count() == 1) immediateSignal = true;
+
     // start a new one
     discoveryAgent.start();
     // we should be active now
@@ -264,6 +270,8 @@ void tst_QBluetoothDeviceDiscoveryAgent::tst_startStopDeviceDiscoveries()
     QVERIFY(errorSpy.isEmpty());
     // stop
     discoveryAgent.stop();
+    if (immediateSignal)
+        QVERIFY(cancelSpy.count() == 2);
 
     // Wait for up to MaxWaitForCancelTime for the cancel to finish
     waitTime = MaxWaitForCancelTime;
@@ -271,12 +279,15 @@ void tst_QBluetoothDeviceDiscoveryAgent::tst_startStopDeviceDiscoveries()
         QTest::qWait(100);
         waitTime-=100;
     }
-
     // we should not be active anymore
     QVERIFY(!discoveryAgent.isActive());
     QVERIFY(errorSpy.isEmpty());
     // should only have 1 cancel
-    QVERIFY(cancelSpy.count() == 1);
+
+    if (immediateSignal)
+        QVERIFY(cancelSpy.count() == 2);
+    else
+        QVERIFY(cancelSpy.count() == 1);
     cancelSpy.clear();
 
     // Starting case 5: start-stop-start: expecting finished signal & no cancel
